@@ -208,11 +208,11 @@ sub create {
     return $self->add_child(@_);
 }
 
-=head3 reparent MAILBOX
+=head3 reparent MAILBOX [NAME]
 
 Reparents this mailbox to be a child of the given
-L<Net::IMAP::Server::Mailbox> C<MAILBOX>.  Should return 0 if the
-reparenting is denied or fails.
+L<Net::IMAP::Server::Mailbox> C<MAILBOX>, with the given C<NAME>.
+Should return 0 if the reparenting is denied or fails.
 
 =cut
 
@@ -224,6 +224,7 @@ sub reparent {
         [ grep { $_ ne $self } @{ $self->parent->children } ] );
     push @{ $parent->children }, $self;
     $self->parent($parent);
+    $self->name(shift) if @_;
     $self->full_path( purge => 1 );
     return 1;
 }
@@ -304,7 +305,7 @@ sub expunge {
     for my $c ( Net::IMAP::Server->concurrent_mailbox_connections($self) ) {
 
         # Also, each connection gets these added to their expunge list
-        push @{ $c->untagged_expunge }, @ids;
+        push @{ $c->_unsent_expunge }, @ids;
     }
 
     return 1;
@@ -326,33 +327,6 @@ sub append {
     return $m;
 }
 
-=head3 status
-
-=cut
-
-sub status {
-    my $self = shift;
-    my (@keys) = @_;
-    $self->poll;
-    my %items;
-    for my $i ( @keys ) {
-        if ( $i eq "MESSAGES" ) {
-            $items{$i} = $self->exists;
-        } elsif ( $i eq "RECENT" ) {
-            $items{$i} = $self->recent;
-        } elsif ( $i eq "UNSEEN" ) {
-            $items{$i} = $self->unseen;
-        } elsif ( $i eq "UIDVALIDITY" ) {
-            my $uidvalidity = $self->uidvalidity;
-            $items{$i} = $uidvalidity if defined $uidvalidity;
-        } elsif ( $i eq "UIDNEXT" ) {
-            my $uidnext = $self->uidnext;
-            $items{$i} = $uidnext if defined $uidnext;
-        }
-    }
-    return %items;
-}
-
 =head3 close
 
 Called when the client selects a different mailbox, or when the
@@ -482,13 +456,13 @@ sub first_unseen {
 
 =head3 unseen
 
-Returns the number of messages which have the C<\Seen> flag set.
+Returns the number of messages which do not have the C<\Seen> flag set.
 
 =cut
 
 sub unseen {
     my $self = shift;
-    return scalar grep { $_->has_flag('\Seen') } @{ $self->messages };
+    return scalar grep { not $_->has_flag('\Seen') } @{ $self->messages };
 }
 
 =head3 permanentflags
@@ -503,6 +477,62 @@ sub permanentflags {
     return $self->flags;
 }
 
+
+=head3 status TYPES
+
+Called when the clients requests a status update (via
+L<Net::IMAP::Server::Command::Status>).  C<TYPES> should be the types
+of information requested, chosen from this list:
+
+=over
+
+=item MESSAGES
+
+The number of messages in the mailbox (via L</exists>)
+
+=item RECENT
+
+The number of messages marked as C<\Recent> (via L</recent>)
+
+=item UNSEEN
+
+The number of messages not marked as C<\Seen> (via L</unseen>)
+
+=item UIDVALIDITY
+
+The C</uidvalidity> of the mailbox.
+
+=item UIDNEXT
+
+The C</uidnext> of the mailbox.
+
+=back
+
+=cut
+
+sub status {
+    my $self = shift;
+    my (@keys) = @_;
+    $self->poll;
+    my %items;
+    for my $i ( @keys ) {
+        if ( $i eq "MESSAGES" ) {
+            $items{$i} = $self->exists;
+        } elsif ( $i eq "RECENT" ) {
+            $items{$i} = $self->recent;
+        } elsif ( $i eq "UNSEEN" ) {
+            $items{$i} = $self->unseen;
+        } elsif ( $i eq "UIDVALIDITY" ) {
+            my $uidvalidity = $self->uidvalidity;
+            $items{$i} = $uidvalidity if defined $uidvalidity;
+        } elsif ( $i eq "UIDNEXT" ) {
+            my $uidnext = $self->uidnext;
+            $items{$i} = $uidnext if defined $uidnext;
+        }
+    }
+    return %items;
+}
+
 =head3 read_only
 
 Returns true if this mailbox is read-only.  By default, the value of
